@@ -6,6 +6,7 @@ from importlib.metadata import metadata
 import yaml
 import toml
 import os
+import traceback
 from making_with_code_cli.mwc_api import MakingWithCodeAPI as API
 from making_with_code_cli.styles import (
     address,
@@ -136,4 +137,8 @@ def update():
                         rel_dir = module_dir.resolve().relative_to(mwc_home)
                         click.echo(confirm(f"Initializing {module['slug']} at {rel_dir}."))
                         click.echo(confirm("See {module['url']} for details."))
-                        G.init_module(module, module_dir)
+                        try:
+                            G.init_module(module, module_dir)
+                        except Exception as e:
+                            msg =  traceback.format_exception(type(e), e, e.__traceback__)
+                            print(''.join(msg))
