@@ -321,6 +321,9 @@ class InstallImageMagick(InstallPackage):
     def is_complete(self):
         return self.executable_on_path("magick")
 
+class InstallHttpie(InstallPackage):
+    package_name = brew_name = apt_name = "httpie"
+
 class GHAuthentication(SetupTask):
     description = "Sign in to github"
     gh_auth_file = Path.home() / ".config/gh/hosts.yml"
@@ -362,7 +365,6 @@ class GitConfiguration(SetupTask):
         (Path.home() / ".gitconfig").touch()
         git_settings = {
             "init.defaultBranch": "main",
-            "commit.template": ".commit_template",
         }
         if self.settings.get('editor') in self.editorcmds:
             editorcmd = self.editorcmds[self.settings.get('editor')]
@@ -372,7 +374,7 @@ class GitConfiguration(SetupTask):
         if self.settings.get('github_email'):
             git_settings["user.email"] = self.settings['github_email']
         for key, val in git_settings.items():
-            run(f"git config --global {key} {val}", shell=True, check=True)
+            run(f'git config --global --replace-all {key} "{val}"', shell=True, check=True)
 
 
 
